@@ -1,26 +1,19 @@
 //
-// "$Id: Fl_XBM_Image.cxx,v 1.1.2.9 2003/01/30 21:43:01 easysw Exp $"
+// "$Id: Fl_XBM_Image.cxx 8864 2011-07-19 04:49:30Z greg.ercolano $"
 //
 // Fl_XBM_Image routines.
 //
-// Copyright 1997-2003 by Bill Spitzak and others.
+// Copyright 1997-2010 by Bill Spitzak and others.
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This library is free software. Distribution and use rights are outlined in
+// the file "COPYING" which should have been included with this file.  If this
+// file is missing or damaged, see the license at:
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
+//     http://www.fltk.org/COPYING.php
 //
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
+// Please report all bugs and problems on the following page:
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+//     http://www.fltk.org/str.php
 //
 // Contents:
 //
@@ -35,17 +28,23 @@
 #include <FL/Fl_XBM_Image.H>
 #include <stdio.h>
 #include <stdlib.h>
+#include <FL/fl_utf8.h>
 #include "flstring.h"
 
 //
 // 'Fl_XBM_Image::Fl_XBM_Image()' - Load an XBM file.
 //
 
+/**  
+  The constructor loads the named XBM file from the given name filename.
+  <P>The destructor free all memory and server resources that are used by 
+  the image.
+*/
 Fl_XBM_Image::Fl_XBM_Image(const char *name) : Fl_Bitmap((const char *)0,0,0) {
   FILE	*f;
   uchar	*ptr;
 
-  if ((f = fopen(name, "rb")) == NULL) return;
+  if ((f = fl_fopen(name, "rb")) == NULL) return;
 
   char buffer[1024];
   char junk[1024];
@@ -86,7 +85,7 @@ Fl_XBM_Image::Fl_XBM_Image(const char *name) : Fl_Bitmap((const char *)0,0,0) {
     }
     const char *a = buffer;
     while (*a && i<n) {
-      int t;
+      unsigned int t;
       if (sscanf(a," 0x%x",&t)>0) {
         *ptr++ = (uchar)t;
 	i ++;
@@ -100,5 +99,5 @@ Fl_XBM_Image::Fl_XBM_Image(const char *name) : Fl_Bitmap((const char *)0,0,0) {
 
 
 //
-// End of "$Id: Fl_XBM_Image.cxx,v 1.1.2.9 2003/01/30 21:43:01 easysw Exp $".
+// End of "$Id: Fl_XBM_Image.cxx 8864 2011-07-19 04:49:30Z greg.ercolano $".
 //
